summaryrefslogtreecommitdiffstats
path: root/chromeos/network
diff options
context:
space:
mode:
authoravi <avi@chromium.org>2015-12-20 19:43:20 -0800
committerCommit bot <commit-bot@chromium.org>2015-12-21 03:44:30 +0000
commit6e1a22dbf2f897399d459f0e1a813decf02ff002 (patch)
tree1514d498779a6799f72b1f0310c7c54ec533494b /chromeos/network
parent77bc325cc5c97ebff1d447ac972fd02e2aec4155 (diff)
downloadchromium_src-6e1a22dbf2f897399d459f0e1a813decf02ff002.zip
chromium_src-6e1a22dbf2f897399d459f0e1a813decf02ff002.tar.gz
chromium_src-6e1a22dbf2f897399d459f0e1a813decf02ff002.tar.bz2
Switch to standard integer types in chromeos/.
BUG=138542 TBR=zelidrag@chromium.org Review URL: https://codereview.chromium.org/1540803002 Cr-Commit-Position: refs/heads/master@{#366324}
Diffstat (limited to 'chromeos/network')
-rw-r--r--chromeos/network/certificate_pattern.cc2
-rw-r--r--chromeos/network/client_cert_resolver.h1
-rw-r--r--chromeos/network/client_cert_resolver_unittest.cc1
-rw-r--r--chromeos/network/client_cert_util.cc1
-rw-r--r--chromeos/network/device_state.h7
-rw-r--r--chromeos/network/dhcp_proxy_script_fetcher_chromeos.h1
-rw-r--r--chromeos/network/fake_network_device_handler.h2
-rw-r--r--chromeos/network/firewall_hole.cc1
-rw-r--r--chromeos/network/geolocation_handler.cc8
-rw-r--r--chromeos/network/geolocation_handler.h6
-rw-r--r--chromeos/network/geolocation_handler_unittest.cc1
-rw-r--r--chromeos/network/host_resolver_impl_chromeos.cc1
-rw-r--r--chromeos/network/host_resolver_impl_chromeos.h1
-rw-r--r--chromeos/network/host_resolver_impl_chromeos_unittest.cc1
-rw-r--r--chromeos/network/managed_network_configuration_handler.h2
-rw-r--r--chromeos/network/managed_network_configuration_handler_impl.h2
-rw-r--r--chromeos/network/managed_network_configuration_handler_unittest.cc1
-rw-r--r--chromeos/network/managed_state.cc10
-rw-r--r--chromeos/network/managed_state.h6
-rw-r--r--chromeos/network/mock_managed_network_configuration_handler.h2
-rw-r--r--chromeos/network/network_activation_handler.h2
-rw-r--r--chromeos/network/network_cert_migrator.h2
-rw-r--r--chromeos/network/network_cert_migrator_unittest.cc1
-rw-r--r--chromeos/network/network_change_notifier_chromeos.cc1
-rw-r--r--chromeos/network/network_change_notifier_chromeos.h2
-rw-r--r--chromeos/network/network_change_notifier_chromeos_unittest.cc3
-rw-r--r--chromeos/network/network_change_notifier_factory_chromeos.h1
-rw-r--r--chromeos/network/network_configuration_handler.cc2
-rw-r--r--chromeos/network/network_configuration_handler.h2
-rw-r--r--chromeos/network/network_configuration_handler_unittest.cc3
-rw-r--r--chromeos/network/network_connection_handler.h2
-rw-r--r--chromeos/network/network_connection_handler_unittest.cc1
-rw-r--r--chromeos/network/network_device_handler.h1
-rw-r--r--chromeos/network/network_device_handler_impl.cc9
-rw-r--r--chromeos/network/network_device_handler_impl.h2
-rw-r--r--chromeos/network/network_device_handler_unittest.cc1
-rw-r--r--chromeos/network/network_event_log.h1
-rw-r--r--chromeos/network/network_handler.h2
-rw-r--r--chromeos/network/network_handler_callbacks.h1
-rw-r--r--chromeos/network/network_ip_config.h1
-rw-r--r--chromeos/network/network_policy_observer.h1
-rw-r--r--chromeos/network/network_profile_handler.cc2
-rw-r--r--chromeos/network/network_profile_handler.h2
-rw-r--r--chromeos/network/network_profile_observer.h1
-rw-r--r--chromeos/network/network_sms_handler.cc26
-rw-r--r--chromeos/network/network_sms_handler.h1
-rw-r--r--chromeos/network/network_state.cc2
-rw-r--r--chromeos/network/network_state.h1
-rw-r--r--chromeos/network/network_state_handler.cc2
-rw-r--r--chromeos/network/network_state_handler.h1
-rw-r--r--chromeos/network/network_state_handler_observer.h2
-rw-r--r--chromeos/network/network_state_handler_unittest.cc3
-rw-r--r--chromeos/network/network_state_unittest.cc4
-rw-r--r--chromeos/network/network_type_pattern.cc2
-rw-r--r--chromeos/network/network_ui_data.h1
-rw-r--r--chromeos/network/network_util.cc7
-rw-r--r--chromeos/network/network_util.h7
-rw-r--r--chromeos/network/network_util_unittest.cc2
-rw-r--r--chromeos/network/onc/onc_certificate_importer.h2
-rw-r--r--chromeos/network/onc/onc_certificate_importer_impl.cc1
-rw-r--r--chromeos/network/onc/onc_certificate_importer_impl.h2
-rw-r--r--chromeos/network/onc/onc_mapper.h1
-rw-r--r--chromeos/network/onc/onc_merger.cc2
-rw-r--r--chromeos/network/onc/onc_normalizer.h1
-rw-r--r--chromeos/network/onc/onc_translator_onc_to_shill.cc1
-rw-r--r--chromeos/network/onc/onc_translator_shill_to_onc.cc2
-rw-r--r--chromeos/network/onc/onc_utils.cc5
-rw-r--r--chromeos/network/onc/onc_utils.h2
-rw-r--r--chromeos/network/onc/onc_utils_unittest.cc1
-rw-r--r--chromeos/network/onc/onc_validator.cc5
-rw-r--r--chromeos/network/onc/onc_validator.h1
-rw-r--r--chromeos/network/policy_applicator.h1
-rw-r--r--chromeos/network/portal_detector/network_portal_detector.h2
-rw-r--r--chromeos/network/portal_detector/network_portal_detector_strategy.cc1
-rw-r--r--chromeos/network/portal_detector/network_portal_detector_strategy.h1
-rw-r--r--chromeos/network/portal_detector/network_portal_detector_stub.h1
-rw-r--r--chromeos/network/prohibited_technologies_handler_unittest.cc1
-rw-r--r--chromeos/network/shill_property_handler.cc3
-rw-r--r--chromeos/network/shill_property_handler.h1
-rw-r--r--chromeos/network/shill_property_handler_unittest.cc3
-rw-r--r--chromeos/network/shill_property_util.cc12
81 files changed, 147 insertions, 69 deletions
diff --git a/chromeos/network/certificate_pattern.cc b/chromeos/network/certificate_pattern.cc
index 7d22088..eba1dfe 100644
--- a/chromeos/network/certificate_pattern.cc
+++ b/chromeos/network/certificate_pattern.cc
@@ -4,6 +4,8 @@
#include "chromeos/network/certificate_pattern.h"
+#include <stddef.h>
+
#include "base/logging.h"
#include "base/values.h"
#include "components/onc/onc_constants.h"
diff --git a/chromeos/network/client_cert_resolver.h b/chromeos/network/client_cert_resolver.h
index 931012b..91d7fb5 100644
--- a/chromeos/network/client_cert_resolver.h
+++ b/chromeos/network/client_cert_resolver.h
@@ -9,7 +9,6 @@
#include <string>
#include <vector>
-#include "base/basictypes.h"
#include "base/macros.h"
#include "base/memory/ref_counted.h"
#include "base/memory/weak_ptr.h"
diff --git a/chromeos/network/client_cert_resolver_unittest.cc b/chromeos/network/client_cert_resolver_unittest.cc
index 4006072..98123a3 100644
--- a/chromeos/network/client_cert_resolver_unittest.cc
+++ b/chromeos/network/client_cert_resolver_unittest.cc
@@ -11,6 +11,7 @@
#include "base/files/file_path.h"
#include "base/files/file_util.h"
#include "base/json/json_reader.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/run_loop.h"
#include "base/strings/stringprintf.h"
diff --git a/chromeos/network/client_cert_util.cc b/chromeos/network/client_cert_util.cc
index 1f810f0..f440dcb 100644
--- a/chromeos/network/client_cert_util.cc
+++ b/chromeos/network/client_cert_util.cc
@@ -6,6 +6,7 @@
#include <cert.h>
#include <pk11pub.h>
+#include <stddef.h>
#include <list>
diff --git a/chromeos/network/device_state.h b/chromeos/network/device_state.h
index 00e49078..97ebd0b 100644
--- a/chromeos/network/device_state.h
+++ b/chromeos/network/device_state.h
@@ -5,6 +5,9 @@
#ifndef CHROMEOS_NETWORK_DEVICE_STATE_H_
#define CHROMEOS_NETWORK_DEVICE_STATE_H_
+#include <stdint.h>
+
+#include "base/macros.h"
#include "base/values.h"
#include "chromeos/network/managed_state.h"
#include "chromeos/network/network_util.h"
@@ -41,7 +44,7 @@ class CHROMEOS_EXPORT DeviceState : public ManagedState {
const std::string& technology_family() const { return technology_family_; }
const std::string& carrier() const { return carrier_; }
const std::string& sim_lock_type() const { return sim_lock_type_; }
- uint32 sim_retries_left() const { return sim_retries_left_; }
+ uint32_t sim_retries_left() const { return sim_retries_left_; }
const std::string& meid() const { return meid_; }
const std::string& imei() const { return imei_; }
const std::string& iccid() const { return iccid_; }
@@ -79,7 +82,7 @@ class CHROMEOS_EXPORT DeviceState : public ManagedState {
std::string technology_family_;
std::string carrier_;
std::string sim_lock_type_;
- uint32 sim_retries_left_;
+ uint32_t sim_retries_left_;
bool sim_present_;
std::string meid_;
std::string imei_;
diff --git a/chromeos/network/dhcp_proxy_script_fetcher_chromeos.h b/chromeos/network/dhcp_proxy_script_fetcher_chromeos.h
index f0d3c4f..27d8d13 100644
--- a/chromeos/network/dhcp_proxy_script_fetcher_chromeos.h
+++ b/chromeos/network/dhcp_proxy_script_fetcher_chromeos.h
@@ -5,6 +5,7 @@
#ifndef CHROMEOS_NETWORK_DHCP_PROXY_SCRIPT_FETCHER_CHROMEOS_H_
#define CHROMEOS_NETWORK_DHCP_PROXY_SCRIPT_FETCHER_CHROMEOS_H_
+#include "base/macros.h"
#include "base/memory/ref_counted.h"
#include "base/memory/weak_ptr.h"
#include "chromeos/chromeos_export.h"
diff --git a/chromeos/network/fake_network_device_handler.h b/chromeos/network/fake_network_device_handler.h
index 79424c7..a7281fa 100644
--- a/chromeos/network/fake_network_device_handler.h
+++ b/chromeos/network/fake_network_device_handler.h
@@ -5,8 +5,8 @@
#ifndef CHROMEOS_NETWORK_FAKE_NETWORK_DEVICE_HANDLER_H_
#define CHROMEOS_NETWORK_FAKE_NETWORK_DEVICE_HANDLER_H_
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "chromeos/chromeos_export.h"
#include "chromeos/network/network_device_handler.h"
diff --git a/chromeos/network/firewall_hole.cc b/chromeos/network/firewall_hole.cc
index 3ad3463..3839b3a 100644
--- a/chromeos/network/firewall_hole.cc
+++ b/chromeos/network/firewall_hole.cc
@@ -5,6 +5,7 @@
#include "chromeos/network/firewall_hole.h"
#include <fcntl.h>
+#include <stdint.h>
#include <unistd.h>
#include "base/bind.h"
diff --git a/chromeos/network/geolocation_handler.cc b/chromeos/network/geolocation_handler.cc
index d4adfb8..0041ccf 100644
--- a/chromeos/network/geolocation_handler.cc
+++ b/chromeos/network/geolocation_handler.cc
@@ -4,6 +4,9 @@
#include "chromeos/network/geolocation_handler.h"
+#include <stddef.h>
+#include <stdint.h>
+
#include "base/bind.h"
#include "base/strings/string_number_conversions.h"
#include "base/values.h"
@@ -35,7 +38,8 @@ void GeolocationHandler::Init() {
}
bool GeolocationHandler::GetWifiAccessPoints(
- WifiAccessPointVector* access_points, int64* age_ms) {
+ WifiAccessPointVector* access_points,
+ int64_t* age_ms) {
if (!wifi_enabled_)
return false;
// Always request updated access points.
@@ -127,7 +131,7 @@ void GeolocationHandler::GeolocationCallback(
entry->GetString(shill::kGeoMacAddressProperty, &wap.mac_address);
std::string age_str;
if (entry->GetString(shill::kGeoAgeProperty, &age_str)) {
- int64 age_ms;
+ int64_t age_ms;
if (base::StringToInt64(age_str, &age_ms)) {
wap.timestamp =
base::Time::Now() - base::TimeDelta::FromMilliseconds(age_ms);
diff --git a/chromeos/network/geolocation_handler.h b/chromeos/network/geolocation_handler.h
index 15b291e..5720364 100644
--- a/chromeos/network/geolocation_handler.h
+++ b/chromeos/network/geolocation_handler.h
@@ -5,6 +5,9 @@
#ifndef CHROMEOS_NETWORK_GEOLOCATION_HANDLER_H_
#define CHROMEOS_NETWORK_GEOLOCATION_HANDLER_H_
+#include <stdint.h>
+
+#include "base/macros.h"
#include "base/memory/weak_ptr.h"
#include "base/time/time.h"
#include "chromeos/dbus/dbus_method_call_status.h"
@@ -37,7 +40,8 @@ class CHROMEOS_EXPORT GeolocationHandler : public ShillPropertyChangedObserver {
// This sends a request for wifi access point data. If data is already
// available, returns |true|, fills |access_points| with the latest access
// point data, and sets |age_ms| to the time since the last update in MS.
- bool GetWifiAccessPoints(WifiAccessPointVector* access_points, int64* age_ms);
+ bool GetWifiAccessPoints(WifiAccessPointVector* access_points,
+ int64_t* age_ms);
bool wifi_enabled() const { return wifi_enabled_; }
diff --git a/chromeos/network/geolocation_handler_unittest.cc b/chromeos/network/geolocation_handler_unittest.cc
index 265f120..6a64a91 100644
--- a/chromeos/network/geolocation_handler_unittest.cc
+++ b/chromeos/network/geolocation_handler_unittest.cc
@@ -2,6 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/message_loop/message_loop.h"
#include "base/strings/string_number_conversions.h"
diff --git a/chromeos/network/host_resolver_impl_chromeos.cc b/chromeos/network/host_resolver_impl_chromeos.cc
index 05def37..ce0cd18 100644
--- a/chromeos/network/host_resolver_impl_chromeos.cc
+++ b/chromeos/network/host_resolver_impl_chromeos.cc
@@ -5,6 +5,7 @@
#include "chromeos/network/host_resolver_impl_chromeos.h"
#include "base/location.h"
+#include "base/macros.h"
#include "base/single_thread_task_runner.h"
#include "base/sys_info.h"
#include "base/thread_task_runner_handle.h"
diff --git a/chromeos/network/host_resolver_impl_chromeos.h b/chromeos/network/host_resolver_impl_chromeos.h
index dba4398..d4acf0f 100644
--- a/chromeos/network/host_resolver_impl_chromeos.h
+++ b/chromeos/network/host_resolver_impl_chromeos.h
@@ -5,6 +5,7 @@
#ifndef CHROMEOS_NETWORK_HOST_RESOLVER_IMPL_CHROMEOS_H_
#define CHROMEOS_NETWORK_HOST_RESOLVER_IMPL_CHROMEOS_H_
+#include "base/macros.h"
#include "base/memory/ref_counted.h"
#include "base/threading/thread_checker.h"
#include "chromeos/chromeos_export.h"
diff --git a/chromeos/network/host_resolver_impl_chromeos_unittest.cc b/chromeos/network/host_resolver_impl_chromeos_unittest.cc
index 8b04c1e..89ebb35 100644
--- a/chromeos/network/host_resolver_impl_chromeos_unittest.cc
+++ b/chromeos/network/host_resolver_impl_chromeos_unittest.cc
@@ -5,6 +5,7 @@
#include "chromeos/network/host_resolver_impl_chromeos.h"
#include "base/location.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/run_loop.h"
#include "base/single_thread_task_runner.h"
diff --git a/chromeos/network/managed_network_configuration_handler.h b/chromeos/network/managed_network_configuration_handler.h
index dfdeb722..172dc0b 100644
--- a/chromeos/network/managed_network_configuration_handler.h
+++ b/chromeos/network/managed_network_configuration_handler.h
@@ -8,9 +8,9 @@
#include <map>
#include <string>
-#include "base/basictypes.h"
#include "base/callback.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "base/observer_list.h"
#include "chromeos/chromeos_export.h"
#include "chromeos/network/network_handler.h"
diff --git a/chromeos/network/managed_network_configuration_handler_impl.h b/chromeos/network/managed_network_configuration_handler_impl.h
index 9cf30ef..76d6c2e 100644
--- a/chromeos/network/managed_network_configuration_handler_impl.h
+++ b/chromeos/network/managed_network_configuration_handler_impl.h
@@ -9,8 +9,8 @@
#include <set>
#include <string>
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/memory/weak_ptr.h"
#include "chromeos/chromeos_export.h"
diff --git a/chromeos/network/managed_network_configuration_handler_unittest.cc b/chromeos/network/managed_network_configuration_handler_unittest.cc
index 6580156..e22b161 100644
--- a/chromeos/network/managed_network_configuration_handler_unittest.cc
+++ b/chromeos/network/managed_network_configuration_handler_unittest.cc
@@ -8,6 +8,7 @@
#include "base/bind.h"
#include "base/bind_helpers.h"
#include "base/location.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/message_loop/message_loop.h"
#include "base/single_thread_task_runner.h"
diff --git a/chromeos/network/managed_state.h b/chromeos/network/managed_state.h
index d33aa8b..86e3b6d 100644
--- a/chromeos/network/managed_state.h
+++ b/chromeos/network/managed_state.h
@@ -5,10 +5,12 @@
#ifndef CHROMEOS_NETWORK_MANAGED_STATE_H_
#define CHROMEOS_NETWORK_MANAGED_STATE_H_
+#include <stdint.h>
+
#include <string>
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "chromeos/chromeos_export.h"
namespace base {
@@ -101,7 +103,7 @@ class CHROMEOS_EXPORT ManagedState {
std::string* out_value);
bool GetUInt32Value(const std::string& key,
const base::Value& value,
- uint32* out_value);
+ uint32_t* out_value);
void set_name(const std::string& name) { name_ = name; }
diff --git a/chromeos/network/mock_managed_network_configuration_handler.h b/chromeos/network/mock_managed_network_configuration_handler.h
index 0af4862..812dfc3 100644
--- a/chromeos/network/mock_managed_network_configuration_handler.h
+++ b/chromeos/network/mock_managed_network_configuration_handler.h
@@ -7,7 +7,7 @@
#include <string>
-#include "base/basictypes.h"
+#include "base/macros.h"
#include "base/values.h"
#include "chromeos/chromeos_export.h"
#include "chromeos/network/managed_network_configuration_handler.h"
diff --git a/chromeos/network/network_activation_handler.h b/chromeos/network/network_activation_handler.h
index f15c73d..8984d2d 100644
--- a/chromeos/network/network_activation_handler.h
+++ b/chromeos/network/network_activation_handler.h
@@ -7,7 +7,7 @@
#include <string>
-#include "base/basictypes.h"
+#include "base/macros.h"
#include "base/memory/weak_ptr.h"
#include "chromeos/chromeos_export.h"
#include "chromeos/network/network_handler_callbacks.h"
diff --git a/chromeos/network/network_cert_migrator.h b/chromeos/network/network_cert_migrator.h
index f4fc4dba..d1bf51a 100644
--- a/chromeos/network/network_cert_migrator.h
+++ b/chromeos/network/network_cert_migrator.h
@@ -5,7 +5,7 @@
#ifndef CHROMEOS_NETWORK_NETWORK_CERT_MIGRATOR_H_
#define CHROMEOS_NETWORK_NETWORK_CERT_MIGRATOR_H_
-#include "base/basictypes.h"
+#include "base/macros.h"
#include "base/memory/weak_ptr.h"
#include "chromeos/cert_loader.h"
#include "chromeos/chromeos_export.h"
diff --git a/chromeos/network/network_cert_migrator_unittest.cc b/chromeos/network/network_cert_migrator_unittest.cc
index ff7191c..d24d67b 100644
--- a/chromeos/network/network_cert_migrator_unittest.cc
+++ b/chromeos/network/network_cert_migrator_unittest.cc
@@ -9,6 +9,7 @@
#include <string>
#include "base/files/file_path.h"
+#include "base/macros.h"
#include "base/run_loop.h"
#include "base/strings/string_number_conversions.h"
#include "chromeos/cert_loader.h"
diff --git a/chromeos/network/network_change_notifier_chromeos.cc b/chromeos/network/network_change_notifier_chromeos.cc
index a232997..2c81c03 100644
--- a/chromeos/network/network_change_notifier_chromeos.cc
+++ b/chromeos/network/network_change_notifier_chromeos.cc
@@ -4,7 +4,6 @@
#include <string>
-#include "base/basictypes.h"
#include "base/bind.h"
#include "base/location.h"
#include "base/strings/string_util.h"
diff --git a/chromeos/network/network_change_notifier_chromeos.h b/chromeos/network/network_change_notifier_chromeos.h
index d8b7292..ed24045 100644
--- a/chromeos/network/network_change_notifier_chromeos.h
+++ b/chromeos/network/network_change_notifier_chromeos.h
@@ -7,9 +7,9 @@
#include <string>
-#include "base/basictypes.h"
#include "base/callback.h"
#include "base/gtest_prod_util.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/memory/weak_ptr.h"
#include "base/single_thread_task_runner.h"
diff --git a/chromeos/network/network_change_notifier_chromeos_unittest.cc b/chromeos/network/network_change_notifier_chromeos_unittest.cc
index 570bc36..4ace6d5 100644
--- a/chromeos/network/network_change_notifier_chromeos_unittest.cc
+++ b/chromeos/network/network_change_notifier_chromeos_unittest.cc
@@ -4,9 +4,10 @@
#include "chromeos/network/network_change_notifier_chromeos.h"
+#include <stddef.h>
+
#include <string>
-#include "base/basictypes.h"
#include "base/message_loop/message_loop.h"
#include "base/strings/string_split.h"
#include "chromeos/network/network_change_notifier_factory_chromeos.h"
diff --git a/chromeos/network/network_change_notifier_factory_chromeos.h b/chromeos/network/network_change_notifier_factory_chromeos.h
index 1a04fbf..a60e5e8 100644
--- a/chromeos/network/network_change_notifier_factory_chromeos.h
+++ b/chromeos/network/network_change_notifier_factory_chromeos.h
@@ -5,7 +5,6 @@
#ifndef CHROMEOS_NETWORK_NETWORK_CHANGE_NOTIFIER_FACTORY_CHROMEOS_H_
#define CHROMEOS_NETWORK_NETWORK_CHANGE_NOTIFIER_FACTORY_CHROMEOS_H_
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
#include "chromeos/chromeos_export.h"
#include "net/base/network_change_notifier_factory.h"
diff --git a/chromeos/network/network_configuration_handler.cc b/chromeos/network/network_configuration_handler.cc
index ac7ea8b..4caf50c 100644
--- a/chromeos/network/network_configuration_handler.cc
+++ b/chromeos/network/network_configuration_handler.cc
@@ -4,12 +4,14 @@
#include "chromeos/network/network_configuration_handler.h"
+#include <stddef.h>
#include "base/bind.h"
#include "base/format_macros.h"
#include "base/guid.h"
#include "base/json/json_writer.h"
#include "base/logging.h"
+#include "base/macros.h"
#include "base/memory/ref_counted.h"
#include "base/stl_util.h"
#include "base/strings/stringprintf.h"
diff --git a/chromeos/network/network_configuration_handler.h b/chromeos/network/network_configuration_handler.h
index 0020c07..6b0bbbd 100644
--- a/chromeos/network/network_configuration_handler.h
+++ b/chromeos/network/network_configuration_handler.h
@@ -10,8 +10,8 @@
#include <string>
#include <vector>
-#include "base/basictypes.h"
#include "base/callback.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/memory/weak_ptr.h"
#include "base/observer_list.h"
diff --git a/chromeos/network/network_configuration_handler_unittest.cc b/chromeos/network/network_configuration_handler_unittest.cc
index 21ff388..be4194a 100644
--- a/chromeos/network/network_configuration_handler_unittest.cc
+++ b/chromeos/network/network_configuration_handler_unittest.cc
@@ -2,12 +2,15 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
+#include <stddef.h>
+
#include <map>
#include <set>
#include "base/bind.h"
#include "base/json/json_writer.h"
#include "base/location.h"
+#include "base/macros.h"
#include "base/message_loop/message_loop.h"
#include "base/single_thread_task_runner.h"
#include "base/stl_util.h"
diff --git a/chromeos/network/network_connection_handler.h b/chromeos/network/network_connection_handler.h
index 36f3a6d..f2ff1a0 100644
--- a/chromeos/network/network_connection_handler.h
+++ b/chromeos/network/network_connection_handler.h
@@ -9,8 +9,8 @@
#include <set>
#include <string>
-#include "base/basictypes.h"
#include "base/callback.h"
+#include "base/macros.h"
#include "base/memory/weak_ptr.h"
#include "base/observer_list.h"
#include "base/time/time.h"
diff --git a/chromeos/network/network_connection_handler_unittest.cc b/chromeos/network/network_connection_handler_unittest.cc
index 0c613be..18bf80d 100644
--- a/chromeos/network/network_connection_handler_unittest.cc
+++ b/chromeos/network/network_connection_handler_unittest.cc
@@ -11,6 +11,7 @@
#include "base/callback.h"
#include "base/files/file_util.h"
#include "base/json/json_reader.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/message_loop/message_loop.h"
#include "base/run_loop.h"
diff --git a/chromeos/network/network_device_handler.h b/chromeos/network/network_device_handler.h
index d682eb9..5f4e81c 100644
--- a/chromeos/network/network_device_handler.h
+++ b/chromeos/network/network_device_handler.h
@@ -8,6 +8,7 @@
#include <string>
#include "base/callback.h"
+#include "base/macros.h"
#include "chromeos/chromeos_export.h"
#include "chromeos/network/network_handler_callbacks.h"
diff --git a/chromeos/network/network_device_handler_impl.cc b/chromeos/network/network_device_handler_impl.cc
index 177fbcc..ccb560e 100644
--- a/chromeos/network/network_device_handler_impl.cc
+++ b/chromeos/network/network_device_handler_impl.cc
@@ -4,6 +4,9 @@
#include "chromeos/network/network_device_handler_impl.h"
+#include <stddef.h>
+#include <stdint.h>
+
#include "base/bind.h"
#include "base/location.h"
#include "base/single_thread_task_runner.h"
@@ -171,8 +174,8 @@ void TDLSSuccessCallback(
}
TDLSOperationParams new_params;
- const int64 kRequestStatusDelayMs = 500;
- int64 request_delay_ms = 0;
+ const int64_t kRequestStatusDelayMs = 500;
+ int64_t request_delay_ms = 0;
if (params.operation == shill::kTDLSStatusOperation) {
// If this is the last operation, or the result is 'Nonexistent',
// return the result.
@@ -228,7 +231,7 @@ void TDLSErrorCallback(
++retry_params.retry_count;
NET_LOG(EVENT) << "TDLS Retry: " << params.retry_count << ": "
<< device_path;
- const int64 kReRequestDelayMs = 1000;
+ const int64_t kReRequestDelayMs = 1000;
base::TimeDelta request_delay;
if (!DBusThreadManager::Get()->GetShillDeviceClient()->GetTestInterface())
request_delay = base::TimeDelta::FromMilliseconds(kReRequestDelayMs);
diff --git a/chromeos/network/network_device_handler_impl.h b/chromeos/network/network_device_handler_impl.h
index 6b77815..31d8854 100644
--- a/chromeos/network/network_device_handler_impl.h
+++ b/chromeos/network/network_device_handler_impl.h
@@ -8,9 +8,9 @@
#include <map>
#include <string>
-#include "base/basictypes.h"
#include "base/callback.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "chromeos/chromeos_export.h"
#include "chromeos/network/network_device_handler.h"
#include "chromeos/network/network_handler.h"
diff --git a/chromeos/network/network_device_handler_unittest.cc b/chromeos/network/network_device_handler_unittest.cc
index 38e078b..8ef65f0 100644
--- a/chromeos/network/network_device_handler_unittest.cc
+++ b/chromeos/network/network_device_handler_unittest.cc
@@ -3,6 +3,7 @@
// found in the LICENSE file.
#include "base/bind.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/message_loop/message_loop.h"
#include "base/values.h"
diff --git a/chromeos/network/network_event_log.h b/chromeos/network/network_event_log.h
index 7c2ba92..7e8f3ce 100644
--- a/chromeos/network/network_event_log.h
+++ b/chromeos/network/network_event_log.h
@@ -8,7 +8,6 @@
#include <deque>
#include <string>
-#include "base/basictypes.h"
#include "base/strings/stringprintf.h"
#include "base/time/time.h"
#include "chromeos/chromeos_export.h"
diff --git a/chromeos/network/network_handler.h b/chromeos/network/network_handler.h
index 93658e0..028b7d5 100644
--- a/chromeos/network/network_handler.h
+++ b/chromeos/network/network_handler.h
@@ -5,7 +5,7 @@
#ifndef CHROMEOS_NETWORK_NETWORK_HANDLER_H_
#define CHROMEOS_NETWORK_NETWORK_HANDLER_H_
-#include "base/basictypes.h"
+#include "base/macros.h"
#include "base/memory/ref_counted.h"
#include "base/memory/scoped_ptr.h"
#include "base/single_thread_task_runner.h"
diff --git a/chromeos/network/network_handler_callbacks.h b/chromeos/network/network_handler_callbacks.h
index 4bdd687..3135bf9 100644
--- a/chromeos/network/network_handler_callbacks.h
+++ b/chromeos/network/network_handler_callbacks.h
@@ -7,7 +7,6 @@
#include <string>
-#include "base/basictypes.h"
#include "base/callback.h"
#include "base/memory/scoped_ptr.h"
#include "chromeos/chromeos_export.h"
diff --git a/chromeos/network/network_ip_config.h b/chromeos/network/network_ip_config.h
index d137fa1..a4efe1e 100644
--- a/chromeos/network/network_ip_config.h
+++ b/chromeos/network/network_ip_config.h
@@ -8,7 +8,6 @@
#include <string>
#include <vector>
-#include "base/basictypes.h"
#include "base/callback.h"
#include "chromeos/chromeos_export.h"
diff --git a/chromeos/network/network_policy_observer.h b/chromeos/network/network_policy_observer.h
index 924a036..cf56b25 100644
--- a/chromeos/network/network_policy_observer.h
+++ b/chromeos/network/network_policy_observer.h
@@ -7,7 +7,6 @@
#include <string>
-#include "base/basictypes.h"
namespace chromeos {
diff --git a/chromeos/network/network_profile_handler.cc b/chromeos/network/network_profile_handler.cc
index 002421a..0d13ee3 100644
--- a/chromeos/network/network_profile_handler.cc
+++ b/chromeos/network/network_profile_handler.cc
@@ -4,6 +4,8 @@
#include "chromeos/network/network_profile_handler.h"
+#include <stddef.h>
+
#include <algorithm>
#include "base/bind.h"
diff --git a/chromeos/network/network_profile_handler.h b/chromeos/network/network_profile_handler.h
index af5045a..5015dd2 100644
--- a/chromeos/network/network_profile_handler.h
+++ b/chromeos/network/network_profile_handler.h
@@ -9,8 +9,8 @@
#include <string>
#include <vector>
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "base/memory/weak_ptr.h"
#include "base/observer_list.h"
#include "chromeos/chromeos_export.h"
diff --git a/chromeos/network/network_profile_observer.h b/chromeos/network/network_profile_observer.h
index 87a7b19..ba7c917 100644
--- a/chromeos/network/network_profile_observer.h
+++ b/chromeos/network/network_profile_observer.h
@@ -7,7 +7,6 @@
#include <string>
-#include "base/basictypes.h"
namespace chromeos {
diff --git a/chromeos/network/network_sms_handler.cc b/chromeos/network/network_sms_handler.cc
index 9c95c7b..88bd7b1 100644
--- a/chromeos/network/network_sms_handler.cc
+++ b/chromeos/network/network_sms_handler.cc
@@ -4,17 +4,21 @@
#include "chromeos/network/network_sms_handler.h"
+#include <stddef.h>
+#include <stdint.h>
+
#include <algorithm>
#include <deque>
#include <vector>
#include "base/bind.h"
+#include "base/macros.h"
#include "base/values.h"
#include "chromeos/dbus/dbus_thread_manager.h"
-#include "chromeos/dbus/shill_device_client.h"
-#include "chromeos/dbus/shill_manager_client.h"
#include "chromeos/dbus/gsm_sms_client.h"
#include "chromeos/dbus/modem_messaging_client.h"
+#include "chromeos/dbus/shill_device_client.h"
+#include "chromeos/dbus/shill_manager_client.h"
#include "chromeos/dbus/sms_client.h"
#include "dbus/object_path.h"
#include "third_party/cros_system_api/dbus/service_constants.h"
@@ -60,8 +64,8 @@ class NetworkSmsHandler::ModemManagerNetworkSmsDeviceHandler
private:
void ListCallback(const base::ListValue& message_list);
- void SmsReceivedCallback(uint32 index, bool complete);
- void GetCallback(uint32 index, const base::DictionaryValue& dictionary);
+ void SmsReceivedCallback(uint32_t index, bool complete);
+ void GetCallback(uint32_t index, const base::DictionaryValue& dictionary);
void DeleteMessages();
void MessageReceived(const base::DictionaryValue& dictionary);
@@ -69,7 +73,7 @@ class NetworkSmsHandler::ModemManagerNetworkSmsDeviceHandler
std::string service_name_;
dbus::ObjectPath object_path_;
bool deleting_messages_;
- std::vector<uint32> delete_queue_;
+ std::vector<uint32_t> delete_queue_;
base::WeakPtrFactory<ModemManagerNetworkSmsDeviceHandler> weak_ptr_factory_;
DISALLOW_COPY_AND_ASSIGN(ModemManagerNetworkSmsDeviceHandler);
@@ -116,7 +120,7 @@ void NetworkSmsHandler::ModemManagerNetworkSmsDeviceHandler::ListCallback(
MessageReceived(*message);
double index = 0;
if (message->GetDoubleWithoutPathExpansion(kIndexKey, &index))
- delete_queue_.push_back(static_cast<uint32>(index));
+ delete_queue_.push_back(static_cast<uint32_t>(index));
}
DeleteMessages();
}
@@ -130,7 +134,7 @@ void NetworkSmsHandler::ModemManagerNetworkSmsDeviceHandler::DeleteMessages() {
return;
}
deleting_messages_ = true;
- uint32 index = delete_queue_.back();
+ uint32_t index = delete_queue_.back();
delete_queue_.pop_back();
DBusThreadManager::Get()->GetGsmSMSClient()->Delete(
service_name_, object_path_, index,
@@ -139,10 +143,8 @@ void NetworkSmsHandler::ModemManagerNetworkSmsDeviceHandler::DeleteMessages() {
weak_ptr_factory_.GetWeakPtr()));
}
-void NetworkSmsHandler::
-ModemManagerNetworkSmsDeviceHandler::SmsReceivedCallback(
- uint32 index,
- bool complete) {
+void NetworkSmsHandler::ModemManagerNetworkSmsDeviceHandler::
+ SmsReceivedCallback(uint32_t index, bool complete) {
// Only handle complete messages.
if (!complete)
return;
@@ -154,7 +156,7 @@ ModemManagerNetworkSmsDeviceHandler::SmsReceivedCallback(
}
void NetworkSmsHandler::ModemManagerNetworkSmsDeviceHandler::GetCallback(
- uint32 index,
+ uint32_t index,
const base::DictionaryValue& dictionary) {
MessageReceived(dictionary);
delete_queue_.push_back(index);
diff --git a/chromeos/network/network_sms_handler.h b/chromeos/network/network_sms_handler.h
index bb7fcb2..eb8ed88 100644
--- a/chromeos/network/network_sms_handler.h
+++ b/chromeos/network/network_sms_handler.h
@@ -7,6 +7,7 @@
#include <string>
+#include "base/macros.h"
#include "base/memory/scoped_vector.h"
#include "base/memory/weak_ptr.h"
#include "base/observer_list.h"
diff --git a/chromeos/network/network_state.cc b/chromeos/network/network_state.cc
index 27d48e9..23381bc 100644
--- a/chromeos/network/network_state.cc
+++ b/chromeos/network/network_state.cc
@@ -4,6 +4,8 @@
#include "chromeos/network/network_state.h"
+#include <stddef.h>
+
#include "base/memory/scoped_ptr.h"
#include "base/strings/string_number_conversions.h"
#include "base/strings/stringprintf.h"
diff --git a/chromeos/network/network_state.h b/chromeos/network/network_state.h
index d388a8e..5a155dd 100644
--- a/chromeos/network/network_state.h
+++ b/chromeos/network/network_state.h
@@ -10,6 +10,7 @@
#include <string>
#include <vector>
+#include "base/macros.h"
#include "base/values.h"
#include "chromeos/network/managed_state.h"
#include "components/onc/onc_constants.h"
diff --git a/chromeos/network/network_state_handler.cc b/chromeos/network/network_state_handler.cc
index e2ea522..dfcc0e6 100644
--- a/chromeos/network/network_state_handler.cc
+++ b/chromeos/network/network_state_handler.cc
@@ -4,6 +4,8 @@
#include "chromeos/network/network_state_handler.h"
+#include <stddef.h>
+
#include "base/bind.h"
#include "base/format_macros.h"
#include "base/guid.h"
diff --git a/chromeos/network/network_state_handler.h b/chromeos/network/network_state_handler.h
index 7dd422c..2477c1a 100644
--- a/chromeos/network/network_state_handler.h
+++ b/chromeos/network/network_state_handler.h
@@ -12,6 +12,7 @@
#include "base/callback_forward.h"
#include "base/gtest_prod_util.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/memory/scoped_vector.h"
#include "base/observer_list.h"
diff --git a/chromeos/network/network_state_handler_observer.h b/chromeos/network/network_state_handler_observer.h
index f2ffd61..a25dc59 100644
--- a/chromeos/network/network_state_handler_observer.h
+++ b/chromeos/network/network_state_handler_observer.h
@@ -8,7 +8,7 @@
#include <string>
#include <vector>
-#include "base/basictypes.h"
+#include "base/macros.h"
#include "chromeos/chromeos_export.h"
namespace chromeos {
diff --git a/chromeos/network/network_state_handler_unittest.cc b/chromeos/network/network_state_handler_unittest.cc
index 3da3831..de832c0 100644
--- a/chromeos/network/network_state_handler_unittest.cc
+++ b/chromeos/network/network_state_handler_unittest.cc
@@ -4,11 +4,14 @@
#include "chromeos/network/network_state_handler.h"
+#include <stddef.h>
+
#include <map>
#include <set>
#include <string>
#include "base/bind.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/message_loop/message_loop.h"
#include "base/values.h"
diff --git a/chromeos/network/network_state_unittest.cc b/chromeos/network/network_state_unittest.cc
index 3ba359a..0d48cdc 100644
--- a/chromeos/network/network_state_unittest.cc
+++ b/chromeos/network/network_state_unittest.cc
@@ -4,8 +4,10 @@
#include "chromeos/network/network_state.h"
-#include "base/basictypes.h"
+#include <stdint.h>
+
#include "base/i18n/streaming_utf8_validator.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/strings/string_number_conversions.h"
#include "base/values.h"
diff --git a/chromeos/network/network_type_pattern.cc b/chromeos/network/network_type_pattern.cc
index fd7d216..65537292 100644
--- a/chromeos/network/network_type_pattern.cc
+++ b/chromeos/network/network_type_pattern.cc
@@ -4,6 +4,8 @@
#include "chromeos/network/network_type_pattern.h"
+#include <stddef.h>
+
#include "chromeos/network/network_event_log.h"
#include "third_party/cros_system_api/dbus/service_constants.h"
diff --git a/chromeos/network/network_ui_data.h b/chromeos/network/network_ui_data.h
index 66cb236..981131ec 100644
--- a/chromeos/network/network_ui_data.h
+++ b/chromeos/network/network_ui_data.h
@@ -7,7 +7,6 @@
#include <string>
-#include "base/basictypes.h"
#include "base/memory/scoped_ptr.h"
#include "chromeos/chromeos_export.h"
#include "components/onc/onc_constants.h"
diff --git a/chromeos/network/network_util.cc b/chromeos/network/network_util.cc
index af660e2..a0f8181 100644
--- a/chromeos/network/network_util.cc
+++ b/chromeos/network/network_util.cc
@@ -4,6 +4,9 @@
#include "chromeos/network/network_util.h"
+#include <stddef.h>
+#include <stdint.h>
+
#include "base/strings/string_number_conversions.h"
#include "base/strings/string_tokenizer.h"
#include "base/strings/string_util.h"
@@ -37,7 +40,7 @@ CellularScanResult::~CellularScanResult() {
namespace network_util {
-std::string PrefixLengthToNetmask(int32 prefix_length) {
+std::string PrefixLengthToNetmask(int32_t prefix_length) {
std::string netmask;
// Return the empty string for invalid inputs.
if (prefix_length < 0 || prefix_length > 32)
@@ -59,7 +62,7 @@ std::string PrefixLengthToNetmask(int32 prefix_length) {
return netmask;
}
-int32 NetmaskToPrefixLength(const std::string& netmask) {
+int32_t NetmaskToPrefixLength(const std::string& netmask) {
int count = 0;
int prefix_length = 0;
base::StringTokenizer t(netmask, ".");
diff --git a/chromeos/network/network_util.h b/chromeos/network/network_util.h
index 47cdcde..b8fee45 100644
--- a/chromeos/network/network_util.h
+++ b/chromeos/network/network_util.h
@@ -10,10 +10,11 @@
// All calls to functions in chromeos_network.h should be made through
// functions provided by this header.
+#include <stdint.h>
+
#include <string>
#include <vector>
-#include "base/basictypes.h"
#include "base/callback.h"
#include "base/memory/scoped_ptr.h"
#include "base/time/time.h"
@@ -75,11 +76,11 @@ namespace network_util {
// Converts a |prefix_length| to a netmask. (for IPv4 only)
// e.g. a |prefix_length| of 24 is converted to a netmask of "255.255.255.0".
// Invalid prefix lengths will return the empty string.
-CHROMEOS_EXPORT std::string PrefixLengthToNetmask(int32 prefix_length);
+CHROMEOS_EXPORT std::string PrefixLengthToNetmask(int32_t prefix_length);
// Converts a |netmask| to a prefixlen. (for IPv4 only)
// e.g. a |netmask| of 255.255.255.0 is converted to a prefixlen of 24
-CHROMEOS_EXPORT int32 NetmaskToPrefixLength(const std::string& netmask);
+CHROMEOS_EXPORT int32_t NetmaskToPrefixLength(const std::string& netmask);
// Returns |shill_mac_address| in aa:bb format.
CHROMEOS_EXPORT std::string FormattedMacAddress(
diff --git a/chromeos/network/network_util_unittest.cc b/chromeos/network/network_util_unittest.cc
index 9ccf8e6..032c08c 100644
--- a/chromeos/network/network_util_unittest.cc
+++ b/chromeos/network/network_util_unittest.cc
@@ -4,6 +4,8 @@
#include "chromeos/network/network_util.h"
+#include <stddef.h>
+
#include "testing/gtest/include/gtest/gtest.h"
#include "third_party/cros_system_api/dbus/service_constants.h"
diff --git a/chromeos/network/onc/onc_certificate_importer.h b/chromeos/network/onc/onc_certificate_importer.h
index 5c2678d..ff934c1 100644
--- a/chromeos/network/onc/onc_certificate_importer.h
+++ b/chromeos/network/onc/onc_certificate_importer.h
@@ -5,8 +5,8 @@
#ifndef CHROMEOS_NETWORK_ONC_ONC_CERTIFICATE_IMPORTER_H_
#define CHROMEOS_NETWORK_ONC_ONC_CERTIFICATE_IMPORTER_H_
-#include "base/basictypes.h"
#include "base/callback_forward.h"
+#include "base/macros.h"
#include "chromeos/chromeos_export.h"
#include "components/onc/onc_constants.h"
#include "net/cert/x509_certificate.h"
diff --git a/chromeos/network/onc/onc_certificate_importer_impl.cc b/chromeos/network/onc/onc_certificate_importer_impl.cc
index f5c97b0..90fc684 100644
--- a/chromeos/network/onc/onc_certificate_importer_impl.cc
+++ b/chromeos/network/onc/onc_certificate_importer_impl.cc
@@ -7,6 +7,7 @@
#include <cert.h>
#include <keyhi.h>
#include <pk11pub.h>
+#include <stddef.h>
#include "base/base64.h"
#include "base/bind.h"
diff --git a/chromeos/network/onc/onc_certificate_importer_impl.h b/chromeos/network/onc/onc_certificate_importer_impl.h
index 5746084..d3e5fb2 100644
--- a/chromeos/network/onc/onc_certificate_importer_impl.h
+++ b/chromeos/network/onc/onc_certificate_importer_impl.h
@@ -9,7 +9,7 @@
#include <string>
#include <vector>
-#include "base/basictypes.h"
+#include "base/macros.h"
#include "base/memory/ref_counted.h"
#include "base/memory/scoped_ptr.h"
#include "base/memory/weak_ptr.h"
diff --git a/chromeos/network/onc/onc_mapper.h b/chromeos/network/onc/onc_mapper.h
index d4b1869..07c5339 100644
--- a/chromeos/network/onc/onc_mapper.h
+++ b/chromeos/network/onc/onc_mapper.h
@@ -7,6 +7,7 @@
#include <string>
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "chromeos/chromeos_export.h"
diff --git a/chromeos/network/onc/onc_merger.cc b/chromeos/network/onc/onc_merger.cc
index 2237b3a..1662920 100644
--- a/chromeos/network/onc/onc_merger.cc
+++ b/chromeos/network/onc/onc_merger.cc
@@ -8,8 +8,8 @@
#include <string>
#include <vector>
-#include "base/basictypes.h"
#include "base/logging.h"
+#include "base/macros.h"
#include "base/values.h"
#include "chromeos/network/onc/onc_signature.h"
#include "components/onc/onc_constants.h"
diff --git a/chromeos/network/onc/onc_normalizer.h b/chromeos/network/onc/onc_normalizer.h
index 2ee0935..1fb18f1 100644
--- a/chromeos/network/onc/onc_normalizer.h
+++ b/chromeos/network/onc/onc_normalizer.h
@@ -5,6 +5,7 @@
#ifndef CHROMEOS_NETWORK_ONC_ONC_NORMALIZER_H_
#define CHROMEOS_NETWORK_ONC_ONC_NORMALIZER_H_
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "chromeos/chromeos_export.h"
#include "chromeos/network/onc/onc_mapper.h"
diff --git a/chromeos/network/onc/onc_translator_onc_to_shill.cc b/chromeos/network/onc/onc_translator_onc_to_shill.cc
index 81d0733..6ce1eab 100644
--- a/chromeos/network/onc/onc_translator_onc_to_shill.cc
+++ b/chromeos/network/onc/onc_translator_onc_to_shill.cc
@@ -15,6 +15,7 @@
#include "base/json/json_reader.h"
#include "base/json/json_writer.h"
#include "base/logging.h"
+#include "base/macros.h"
#include "base/strings/string_util.h"
#include "base/values.h"
#include "chromeos/network/onc/onc_signature.h"
diff --git a/chromeos/network/onc/onc_translator_shill_to_onc.cc b/chromeos/network/onc/onc_translator_shill_to_onc.cc
index 2861737..62aa868 100644
--- a/chromeos/network/onc/onc_translator_shill_to_onc.cc
+++ b/chromeos/network/onc/onc_translator_shill_to_onc.cc
@@ -6,10 +6,10 @@
#include <string>
-#include "base/basictypes.h"
#include "base/json/json_reader.h"
#include "base/json/json_writer.h"
#include "base/logging.h"
+#include "base/macros.h"
#include "base/strings/string_util.h"
#include "base/values.h"
#include "chromeos/network/network_profile_handler.h"
diff --git a/chromeos/network/onc/onc_utils.cc b/chromeos/network/onc/onc_utils.cc
index 771c51b..55f5091 100644
--- a/chromeos/network/onc/onc_utils.cc
+++ b/chromeos/network/onc/onc_utils.cc
@@ -4,6 +4,9 @@
#include "chromeos/network/onc/onc_utils.h"
+#include <stddef.h>
+#include <stdint.h>
+
#include "base/base64.h"
#include "base/json/json_reader.h"
#include "base/logging.h"
@@ -768,7 +771,7 @@ net::ProxyServer ConvertOncProxyLocationToHostPort(
return net::ProxyServer(
proxy_server.scheme(),
net::HostPortPair(proxy_server.host_port_pair().host(),
- static_cast<uint16>(port)));
+ static_cast<uint16_t>(port)));
}
void AppendProxyServerForScheme(const base::DictionaryValue& onc_manual,
diff --git a/chromeos/network/onc/onc_utils.h b/chromeos/network/onc/onc_utils.h
index 6a56e96..b70a7df 100644
--- a/chromeos/network/onc/onc_utils.h
+++ b/chromeos/network/onc/onc_utils.h
@@ -9,7 +9,7 @@
#include <string>
#include <vector>
-#include "base/basictypes.h"
+#include "base/macros.h"
#include "base/memory/ref_counted.h"
#include "base/memory/scoped_ptr.h"
#include "chromeos/chromeos_export.h"
diff --git a/chromeos/network/onc/onc_utils_unittest.cc b/chromeos/network/onc/onc_utils_unittest.cc
index 30053f1..4c20d99 100644
--- a/chromeos/network/onc/onc_utils_unittest.cc
+++ b/chromeos/network/onc/onc_utils_unittest.cc
@@ -8,6 +8,7 @@
#include "base/json/json_file_value_serializer.h"
#include "base/logging.h"
+#include "base/macros.h"
#include "base/strings/string_number_conversions.h"
#include "base/values.h"
#include "chromeos/chromeos_test_utils.h"
diff --git a/chromeos/network/onc/onc_validator.cc b/chromeos/network/onc/onc_validator.cc
index ee681aa..12c602f 100644
--- a/chromeos/network/onc/onc_validator.cc
+++ b/chromeos/network/onc/onc_validator.cc
@@ -4,6 +4,9 @@
#include "chromeos/network/onc/onc_validator.h"
+#include <stddef.h>
+#include <stdint.h>
+
#include <algorithm>
#include "base/json/json_writer.h"
@@ -452,7 +455,7 @@ bool Validator::ValidateSSIDAndHexSSID(base::DictionaryValue* object) {
std::string hex_ssid_string;
if (object->GetStringWithoutPathExpansion(::onc::wifi::kHexSSID,
&hex_ssid_string)) {
- std::vector<uint8> decoded_ssid;
+ std::vector<uint8_t> decoded_ssid;
if (!base::HexStringToBytes(hex_ssid_string, &decoded_ssid)) {
LOG(ERROR) << MessageHeader() << "Field " << ::onc::wifi::kHexSSID
<< " is not a valid hex representation: \"" << hex_ssid_string
diff --git a/chromeos/network/onc/onc_validator.h b/chromeos/network/onc/onc_validator.h
index adacbda..07be183 100644
--- a/chromeos/network/onc/onc_validator.h
+++ b/chromeos/network/onc/onc_validator.h
@@ -9,6 +9,7 @@
#include <string>
#include <vector>
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "chromeos/chromeos_export.h"
#include "chromeos/network/onc/onc_mapper.h"
diff --git a/chromeos/network/policy_applicator.h b/chromeos/network/policy_applicator.h
index bca3b06..032f4f3 100644
--- a/chromeos/network/policy_applicator.h
+++ b/chromeos/network/policy_applicator.h
@@ -9,6 +9,7 @@
#include <set>
#include <string>
+#include "base/macros.h"
#include "base/memory/scoped_vector.h"
#include "base/memory/weak_ptr.h"
#include "base/values.h"
diff --git a/chromeos/network/portal_detector/network_portal_detector.h b/chromeos/network/portal_detector/network_portal_detector.h
index 611cb64..f5cf756 100644
--- a/chromeos/network/portal_detector/network_portal_detector.h
+++ b/chromeos/network/portal_detector/network_portal_detector.h
@@ -5,7 +5,7 @@
#ifndef CHROMEOS_NETWORK_PORTAL_DETECTOR_NETWORK_PORTAL_DETECTOR_H_
#define CHROMEOS_NETWORK_PORTAL_DETECTOR_NETWORK_PORTAL_DETECTOR_H_
-#include "base/basictypes.h"
+#include "base/macros.h"
#include "chromeos/chromeos_export.h"
#include "chromeos/network/portal_detector/network_portal_detector_strategy.h"
#include "net/url_request/url_fetcher.h"
diff --git a/chromeos/network/portal_detector/network_portal_detector_strategy.cc b/chromeos/network/portal_detector/network_portal_detector_strategy.cc
index c45466f..185d441 100644
--- a/chromeos/network/portal_detector/network_portal_detector_strategy.cc
+++ b/chromeos/network/portal_detector/network_portal_detector_strategy.cc
@@ -5,6 +5,7 @@
#include "chromeos/network/portal_detector/network_portal_detector_strategy.h"
#include "base/logging.h"
+#include "base/macros.h"
#include "chromeos/network/network_handler.h"
#include "chromeos/network/network_state.h"
#include "chromeos/network/network_state_handler.h"
diff --git a/chromeos/network/portal_detector/network_portal_detector_strategy.h b/chromeos/network/portal_detector/network_portal_detector_strategy.h
index 84d4853..22d4ec5 100644
--- a/chromeos/network/portal_detector/network_portal_detector_strategy.h
+++ b/chromeos/network/portal_detector/network_portal_detector_strategy.h
@@ -5,7 +5,6 @@
#ifndef CHROMEOS_NETWORK_PORTAL_DETECTOR_NETWORK_PORTAL_DETECTOR_STRATEGY_H_
#define CHROMEOS_NETWORK_PORTAL_DETECTOR_NETWORK_PORTAL_DETECTOR_STRATEGY_H_
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
diff --git a/chromeos/network/portal_detector/network_portal_detector_stub.h b/chromeos/network/portal_detector/network_portal_detector_stub.h
index c2e921e..16e9fd0 100644
--- a/chromeos/network/portal_detector/network_portal_detector_stub.h
+++ b/chromeos/network/portal_detector/network_portal_detector_stub.h
@@ -5,6 +5,7 @@
#ifndef CHROMEOS_NETWORK_PORTAL_DETECTOR_NETWORK_PORTAL_DETECTOR_STUB_H_
#define CHROMEOS_NETWORK_PORTAL_DETECTOR_NETWORK_PORTAL_DETECTOR_STUB_H_
+#include "base/macros.h"
#include "chromeos/network/portal_detector/network_portal_detector.h"
namespace chromeos {
diff --git a/chromeos/network/prohibited_technologies_handler_unittest.cc b/chromeos/network/prohibited_technologies_handler_unittest.cc
index 68e186f..931e727 100644
--- a/chromeos/network/prohibited_technologies_handler_unittest.cc
+++ b/chromeos/network/prohibited_technologies_handler_unittest.cc
@@ -9,6 +9,7 @@
#include "base/bind.h"
#include "base/callback.h"
#include "base/json/json_reader.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/message_loop/message_loop.h"
#include "base/run_loop.h"
diff --git a/chromeos/network/shill_property_handler.cc b/chromeos/network/shill_property_handler.cc
index 41482be..a3f77a5 100644
--- a/chromeos/network/shill_property_handler.cc
+++ b/chromeos/network/shill_property_handler.cc
@@ -4,10 +4,13 @@
#include "chromeos/network/shill_property_handler.h"
+#include <stddef.h>
+
#include <sstream>
#include "base/bind.h"
#include "base/format_macros.h"
+#include "base/macros.h"
#include "base/stl_util.h"
#include "base/strings/string_util.h"
#include "base/values.h"
diff --git a/chromeos/network/shill_property_handler.h b/chromeos/network/shill_property_handler.h
index b4b6202..2fb49d0 100644
--- a/chromeos/network/shill_property_handler.h
+++ b/chromeos/network/shill_property_handler.h
@@ -11,6 +11,7 @@
#include <string>
#include <vector>
+#include "base/macros.h"
#include "base/memory/weak_ptr.h"
#include "chromeos/dbus/dbus_method_call_status.h"
#include "chromeos/dbus/shill_property_changed_observer.h"
diff --git a/chromeos/network/shill_property_handler_unittest.cc b/chromeos/network/shill_property_handler_unittest.cc
index 7593194..6a23238 100644
--- a/chromeos/network/shill_property_handler_unittest.cc
+++ b/chromeos/network/shill_property_handler_unittest.cc
@@ -4,11 +4,14 @@
#include "chromeos/network/shill_property_handler.h"
+#include <stddef.h>
+
#include <map>
#include <set>
#include <string>
#include "base/bind.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/message_loop/message_loop.h"
#include "base/values.h"
diff --git a/chromeos/network/shill_property_util.cc b/chromeos/network/shill_property_util.cc
index c5cafc8..e47c7ad 100644
--- a/chromeos/network/shill_property_util.cc
+++ b/chromeos/network/shill_property_util.cc
@@ -4,6 +4,8 @@
#include "chromeos/network/shill_property_util.h"
+#include <stdint.h>
+
#include <set>
#include "base/i18n/icu_encoding_detection.h"
@@ -28,15 +30,15 @@ namespace {
// Replace non UTF8 characters in |str| with a replacement character.
std::string ValidateUTF8(const std::string& str) {
std::string result;
- for (int32 index = 0; index < static_cast<int32>(str.size()); ++index) {
- uint32 code_point_out;
+ for (int32_t index = 0; index < static_cast<int32_t>(str.size()); ++index) {
+ uint32_t code_point_out;
bool is_unicode_char = base::ReadUnicodeCharacter(
str.c_str(), str.size(), &index, &code_point_out);
- const uint32 kFirstNonControlChar = 0x20;
+ const uint32_t kFirstNonControlChar = 0x20;
if (is_unicode_char && (code_point_out >= kFirstNonControlChar)) {
base::WriteUnicodeCharacter(code_point_out, &result);
} else {
- const uint32 kReplacementChar = 0xFFFD;
+ const uint32_t kReplacementChar = 0xFFFD;
// Puts kReplacementChar if character is a control character [0,0x20)
// or is not readable UTF8.
base::WriteUnicodeCharacter(kReplacementChar, &result);
@@ -86,7 +88,7 @@ std::string GetSSIDFromProperties(const base::DictionaryValue& properties,
}
std::string ssid;
- std::vector<uint8> raw_ssid_bytes;
+ std::vector<uint8_t> raw_ssid_bytes;
if (base::HexStringToBytes(hex_ssid, &raw_ssid_bytes)) {
ssid = std::string(raw_ssid_bytes.begin(), raw_ssid_bytes.end());
VLOG(2) << "GetSSIDFromProperties: " << name << " HexSsid=" << hex_ssid
diff --git a/chromeos/network/managed_state.cc b/chromeos/network/managed_state.cc
index 75fce5b..9a6c1b2 100644
--- a/chromeos/network/managed_state.cc
+++ b/chromeos/network/managed_state.cc
@@ -4,6 +4,8 @@
#include "chromeos/network/managed_state.h"
+#include <stdint.h>
+
#include "base/logging.h"
#include "base/values.h"
#include "chromeos/network/device_state.h"
@@ -125,17 +127,17 @@ bool ManagedState::GetStringValue(const std::string& key,
bool ManagedState::GetUInt32Value(const std::string& key,
const base::Value& value,
- uint32* out_value) {
+ uint32_t* out_value) {
// base::Value restricts the number types to BOOL, INTEGER, and DOUBLE only.
// uint32 will automatically get converted to a double, which is why we try
// to obtain the value as a double (see dbus/values_util.h).
- uint32 new_value;
+ uint32_t new_value;
double double_value;
if (!value.GetAsDouble(&double_value) || double_value < 0) {
NET_LOG_ERROR("Error parsing state value", path() + "." + key);
return false;
}
- new_value = static_cast<uint32>(double_value);
+ new_value = static_cast<uint32_t>(double_value);
if (*out_value == new_value)
return false;
*out_value = new_value;
@@ -125,17 +127,17 @@ bool ManagedState::GetStringValue(const std::string& key,
// base::Value restricts the number types to BOOL, INTEGER, and DOUBLE only.
- // uint32 will automatically get converted to a double, which is why we try
+ // uint32_t will automatically get converted to a double, which is why we try
// to obtain the value as a double (see dbus/values_util.h).